jactorch.functional.grad
========================

.. automodule:: jactorch.functional.grad

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      GradMulti
      ZeroGradV1
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      grad_multi
      zero_grad
      zero_grad_v1
      zero_grad_v2
   
   

   
   
   








.. rubric:: Class GradMulti
.. autoclass:: GradMulti
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class ZeroGradV1
.. autoclass:: ZeroGradV1
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







.. rubric:: Functions

.. autofunction:: grad_multi

.. autofunction:: zero_grad

.. autofunction:: zero_grad_v1

.. autofunction:: zero_grad_v2


